BFGraph: myColors Class Reference

BFGraph

Public Member Functions
myColors Class Reference

Inherits CDBG_Data_t< myColors >.

## Public Member Functions
void | join (const myColors &data, CompactedDBG< myColors > &cdbg)
void | split (const size_t pos, const size_t len, myColors &new_data, CompactedDBG< myColors > &cdbg) const
void | add (int color)
void | erase (int color)
void | print () const

The documentation for this class was generated from the following file:

- src/BFGraph.cpp